export declare const BASTION_INSTANCE_CLOUD_INIT = "\n#cloud-config\nrepo_update: true\nrepo_upgrade: all\n\nwrite_files:\n  - path: /opt/basti/stop-if-not-used.sh\n    owner: root:root\n    permissions: \"0544\"\n    content: |\n      #!/bin/bash\n      \n      set -e;\n      \n      # Stopping instance in case of any error to prevent it from running forever\n      handle_error() {\n        echo \"[$(date)] Error running script. Stopping instance.\"\n        \n        /sbin/shutdown -h now\n      }\n\n      trap handle_error ERR\n\n      echo \"[$(date)] ==========\"\n\n      echo \"[$(date)] Retrieving instance metadata.\"\n      imdsToken=$(curl -s -X PUT \"http://169.254.169.254/latest/api/token\" -H \"X-aws-ec2-metadata-token-ttl-seconds: 21600\")\n      bastionInstanceRegion=$(curl -s \"http://169.254.169.254/latest/meta-data/placement/region\" -H \"X-aws-ec2-metadata-token: $imdsToken\")\n      bastionInstanceId=$(curl -s \"http://169.254.169.254/latest/meta-data/instance-id\" -H \"X-aws-ec2-metadata-token: $imdsToken\")\n\n      export AWS_DEFAULT_REGION=$bastionInstanceRegion\n\n      echo \"[$(date)] Retrieving last in use tag.\"\n      lastInUse=$(aws ec2 describe-instances \\\n        --instance-ids $bastionInstanceId \\\n        --query \"Reservations[0].Instances[0].Tags[?Key=='basti:in-use'].Value\" \\\n        --output text\n      )\n      inUseThreshold=$(date -d \"now - 5 minutes\" -u +\"%Y-%m-%dT%H:%M:%SZ\")\n\n      if [[ $lastInUse < $inUseThreshold ]]; then\n        echo \"[$(date)] Instance is not in use.\"\n        \n        echo \"[$(date)] Retrieving last updated tag.\"\n        lastUpdated=$(aws ec2 describe-instances \\\n          --instance-ids $bastionInstanceId \\\n          --query \"Reservations[0].Instances[0].Tags[?Key=='basti:updated'].Value\" \\\n          --output text\n        )\n        lastUpdatedThreshold=$(date -d \"now - 1 day\" -u +\"%Y-%m-%dT%H:%M:%SZ\")\n\n        if [[ $lastUpdated < $lastUpdatedThreshold ]]; then\n          echo \"[$(date)] Updating instance.\"\n\n          echo \"[$(date)] Setting updating tag.\"\n          aws ec2 create-tags \\\n            --resources $bastionInstanceId \\\n            --tags Key=basti:updating,Value=$(date -u +\"%Y-%m-%dT%H:%M:%SZ\")\n\n          echo \"[$(date)] Updating packages.\"\n          yum update -y\n\n          echo \"[$(date)] Setting updated tag.\"\n          aws ec2 create-tags \\\n            --resources $bastionInstanceId \\\n            --tags Key=basti:updated,Value=$(date -u +\"%Y-%m-%dT%H:%M:%SZ\")\n        fi\n\n        echo \"[$(date)] Stopping instance.\"\n        /sbin/shutdown -h now\n      fi\n\n      echo \"[$(date)] Instance is in use.\"\n\n  - path: /var/log/basti/stop-if-not-used.log\n    owner: root:root\n    permissions: \"0644\"\n    content: \"\"\n\n  - path: /etc/cron.d/stop-if-not-used\n    owner: root:root\n    permissions: \"0444\"\n    content: \"* * * * * root flock -xn /var/lock/stop-if-not-used.lock -c /opt/basti/stop-if-not-used.sh &>> /var/log/basti/stop-if-not-used.log\\n\"\n";
